
# Change Log

## 0.2.0 (2025-03-14)

ENHANCEMENTS:

* Improved format for handling database connection details in the config.
* Added Postgres support.

BUG FIXES:
* Fixed sorting of DuckDB Structs

BREAKING CHANGES:
* Existing configs are not compatible with this version.
